# Automation Toolbox for Machine learning in water Networks
The Automation Toolbox for Machine learning in water Networks (`atmn`) offers a selection of easy to use tools for generating and working with synthetic water network data. It builds on the `wntr` python package to use the EPANET simulator for simulation of leaks and sensor faults in water networks.

For full documentation and example code, please refer to our [Github Page](https://github.com/HammerLabML/atmn).
